/* 
 * (c) Copyright IBM Corp. 2005, 2006. All Rights Reserved. 
 * Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and conditions in the IBM International Program License Agreement. 
 */
package importer;

import java.util.Iterator;

import com.ibm.rational.test.mt.importer.interfaces.IMTAImportNode;

/**
 * This is a Rational Manual Test statement.
 */
public class ExampleMTAImportNode implements IMTAImportNode 
{
	int type = TYPE_STEP;			// statement type (i.e. TYPE_STEP, TYPE_VP, etc.)
	String name = null;				// statement name (appears in Outline View)
	String description = null;		// statement description (appears in Editor)
	String[] attachments = null;	// attachments (array of filenames)
	
	// variables used in hardcoding node iteration
	static int nodeNum = 0;
	
	/**
	 * Get the next sibling node. This enumerates the siblings of a node.
	 * @return IMTAImportNode
	 */
	public IMTAImportNode getNext()
	{
		// For those using this method as a template the realistic thing
		// to do is determine the siblings of a statement and return the
		// next sibling.
		// In this example the siblings are hardcoded.
		if (nodeNum++ == 0)
		{
			return createNode(
					IMTAImportNode.TYPE_BLOCK,
					"New customer dialog",
					"Test controls of the new customer dialog",
					null );
		}
		else if (nodeNum++ == 1)
		{
			return createNode(
					IMTAImportNode.TYPE_TESTCASE,
					"Overall result",
					"Did the test case pass?",
					null );
		}
		
		return null;	// no more statements
	}

	/**
	 * Get an iterator that returns the child nodes of this node.
	 * This only makes sense if this is a block node.  That said
	 * if this is not a block or the block has no children then an iterator
	 * should be returned but not have any nodes to iterate through.
	 * @return iterator of IMTAImportNode(s)
	 */
	public Iterator getChildNodes( )
	{
		return new ExampleNodeIterator();
	}

	/**
	 * Returns the type of this node. The type could be one of the following.
	 * TYPE_STEP, TYPE_VP, TYPE_BLOCK and TYPE_TESTCASE
	 * @return integer
	 */
	public int getType()
	{
		return type;
	}
	
	/**
	 * Set the type of this node.  The type could be one of the following.
	 * TYPE_STEP, TYPE_VP, TYPE_BLOCK and TYPE_TESTCASE.
	 * @param type
	 */
	public void setType( int type )
	{
		this.type = type;
	}

	/**
	 * Get the name of this node.  This is displayed in the Outline View.
	 * @return String
	 */
	public String getName()
	{
		return name;
	}
	
	/**
	 * Set the name of this node.  This is displayed in the Outline View.
	 * @param name
	 */
	public void setName( String name )
	{
		this.name = name;
	}

	/**
	 * Get the description of this node.  This is displayed in the editor.
	 * @return String
	 */
	public String getDescription()
	{
		return description;
	}
	
	/**
	 * Set the description of this node.  This is displayed in the editor.
	 * @return String
	 */
	public void setDescription( String description )
	{
		this.description = description;
	}

	/**
	 * Get the list of attachment file names that are associated with this node
	 * @return String[]
	 */
	public String[] getAttachments()
	{
		return attachments;
	}

	/**
	 * Set the list of attachment file names that are associated with this node
	 * @param String[]
	 */
	public void setAttachments( String[] attachments )
	{
		this.attachments = attachments;
	}

	/**
	 * Called at the end of the node's life-cycle.  Release the resources 
	 * allocated by this node. 
	 */
	public void destroy()
	{
		// node has no resources that need freeing
	}
	
	/**
	 * Create a node and initializes it.
	 * @param type
	 * @param name
	 * @param description
	 * @param attachments
	 * @return
	 */
	public static IMTAImportNode createNode( 
			int type, String name, String description, String[] attachments )
	{
		ExampleMTAImportNode node = new ExampleMTAImportNode();
		
		// type is required.
		node.setType( type );
		
		// name is optional.
		// If there is no name the first 32 chars of the description are
		// displayed in the Outline view.
		if (name != null && !name.equals( "" ))
			node.setName( name );
		
		// description is required.
		node.setDescription( description );
		
		// attachments are optional.
		// Once the test is saved the attachments are stored in the Manual
		// Test file so the original can be moved/deleted/etc.
		node.setAttachments( attachments );
		
		return node;
	}
}
