/* 
 * (c) Copyright IBM Corp. 2005, 2006. All Rights Reserved. 
 * Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and conditions in the IBM International Program License Agreement. 
 */
package importer;

import java.util.Iterator;
import java.util.NoSuchElementException;

import com.ibm.rational.test.mt.importer.interfaces.IMTAImportNode;

/**
 * Iterates over all documents being imported
 */
public class ExampleSourceIterator implements Iterator
{
	static final int UNINITIALIZED = -1;
	
	String[] filenames = null;
	int currentIndex = UNINITIALIZED;
	
	public ExampleSourceIterator(String[] filenames)
	{
		this.filenames = filenames;
	}
	
	/**
	 * Return true if there are more document to import
	 * @return true=more document, false=no more documents
	 */
	public boolean hasNext()
	{
		if (currentIndex == UNINITIALIZED)
			return ((filenames != null) && (filenames.length > 0));
		
		return (currentIndex < filenames.length-1);
	}

	/**
	 * Return the next root node of the next document to import
	 * @return root node
	 */
	public Object next()
	{
		if (currentIndex == UNINITIALIZED)
		{
			if ((filenames != null) && (filenames.length > 0))
			{
				currentIndex = 0;
				
				// For those using this method as a template the realistic thing
				// to do is open filenames[currentIndex] and return an IMTAImportNode
				// that represents the first statement in the file.
				// In this example the first statement is hardcoded.
				// An attachment was added as an example but it does not in fact exist.
				return ExampleMTAImportNode.createNode(
						IMTAImportNode.TYPE_STEP,
						null,
						"Test the new customer dialog",
						new String[] { "C:\\MyTest\\attachments\\Design.doc" } );
			}
		}
		else if (++currentIndex < filenames.length-1)
		{
			// For those using this method as a template the realistic thing
			// to do is open filenames[currentIndex] and return an IMTAImportNode
			// that represents the first statement in the file.
			// In this example the filenames array has only one element so
			// this code will never be reached.
			return null;
		}
		
		throw new NoSuchElementException();
	}

	/**
	 * This operation not supported.
	 */
	public void remove()
	{
		throw new UnsupportedOperationException();
	}
}
